/*                            ACCESS.C                             */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

/* More error checking is needed */

#include "constant.h"
#include "pdutags.h"
#include "putget.h"
#include "session.h"
#include "string.h"

enum access_control_tags
{
    SecurityChallenge = 37,
    SecurityChallengeResponse
};

/*--------------------------------------------------------------*
 |                DECODE_ACCESSCONTROL_REQUEST                  |
 | Function:                                                    |
 |    Decode the Access Control Request PDU                     |
 | Parameters:                                                  |
 |    session   : Session information.                          |
 |    challenge : String to place challenge.                    |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

void Decode_AccessControl_Request(SESSION *session,
                                  STRING   *challenge)
{
    DATA_DIR *PAccess;

    PAccess = get_begin(session->pdu, AccessControlRequest);
    if (PAccess == NULL_DIR) return;

    get_string(PAccess, SecurityChallenge, challenge, REQUIRED);
}

/*--------------------------------------------------------------*
 |                ENCODE_ACCESSCONTROL_REQUEST                  |
 | Function:                                                    |
 |    Encode the Access Control Request PDU                     |
 | Parameters:                                                  |
 |    session   : Session information.                          |
 |    security_code : String of the security code.              |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

void Encode_AccessControl_Response(SESSION  *session,
                                   STRING   *security_code)
{
    DATA_DIR *PAccess;

    PAccess = put_begin(session->pdu, AccessControlResponse);
    if (PAccess == NULL_DIR) return;

    if (session->reference)
        put_cstring(PAccess, ReferenceId, session->reference);

    if (security_code && security_code->length > 0)
        put_string(PAccess, SecurityChallengeResponse, security_code);
    else
        put_cstring(PAccess, SecurityChallengeResponse, " ");
}

/*--------------------------------------------------------------*
 |                 REPLY_ACCESS_CONTROL_PDU                     |
 | Function:                                                    |
 |    Reply to an access control pdu request.                   |
 | Parameters:                                                  |
 |    session : Session information.                            |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |    Responds to the access control with a blank password      |
 |    unless there is an access control routine to call.        |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

int reply_access_control_pdu(SESSION *session)
{
    STRING   challenge;
    STRING   security_code;
    char     security_buffer[80];

    STRING_SET(security_code, 0, security_buffer);

    Decode_AccessControl_Request(session, &challenge);

    /* Check if a access routine should be called */

    if (session->access_control)
        (*session->access_control)(session, &challenge, &security_code);

    Encode_AccessControl_Response(session, &security_code);

    return OK;
}
