/*                             BIB1.H                              */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */
/* Log:
 * 04/25/94  slh  added bjordan's HOST_ITEM record
 * 6/13/94   wdc  Added in USE attributes from v3d10
 */

#ifndef BIB1_H
#define BIB1_H

#ifndef DATABASE_H
#include "database.h"
#endif

/* Bib-1 type attributes */

#define BIB1_SET_ID             "1.2.840.10003.3.1"

#ifdef MARKER

static INDEX bib1_indexes[] =
{
    {"AUTHOR",          "", 0, 1003, 0, 3, 6, 0, 0},     /* Personal Author */
    {"TITLE",           "", 0, 4,    0, 3, 6, 0, 0},     /* Personal Author */
    {"SUBJECT",         "", 0, 1017, 0, 3, 6, 0, 0},     /* Subject (Any)   */
    {"ABSTRACT",        "", 0, 62,   0, 0, 0, 0, 0},     /* Abstract        */
    {"ORGANIZATION",    "", 0, 2,    0, 3, 6, 0, 0},     /* Organization */
    {"THESAURUS",       "", 0, 21,   0, 3, 6, 0, 0},     /* Thesaurus */
    {"PUBLICATION",     "", 0, 5,    0, 3, 6, 0, 0},     /* Publication */
    {"TP",              "", 0, 4,    0, 3, 1, 0, 0},     /* Title Phrase */
    {"SP",              "", 0, 1017, 0, 3, 1, 0, 0},     /* Subject Phrase */
    {"THP",             "", 0, 21,   0, 3, 1, 0, 0},     /* Thesaurus Phrase */
    {"PP",              "", 0, 5,    0, 3, 1, 0, 0},     /* Publication Phrase */
    {"OP",              "", 0, 2,    0, 3, 1, 0, 0},     /* Organization Phrase */
    {"ISBN",            "", 0, 7,    0, 2, 2, 0, 0},     /* ISBN */
    {"ISSN",            "", 0, 8,    0, 2, 2, 0, 0},     /* ISSN */
    {"LCCN",            "", 0, 9,    0, 2, 2, 0, 0},     /* LC Card Number */
    {"DATE",            "", 0, 30,   0, 3, 6, 0, 0},     /* Date */
    {"PUBDATE",         "", 0, 31,   0, 3, 6, 0, 0},     /* Publication Date */
    {"LANGUAGE",        "", 0, 54,   0, 3, 6, 0, 0},     /* Language */
    {"CODEN",           "", 0, 60,   0, 2, 2, 0, 0}      /* CODEN */
};

#else /* MARKER */

/*
  to be done: the rpn query should be altered so that
  Willow assumes that what is passed in is a word list
  unless the keyword adj is used in which case it is considered
  to be a phrase. We set a default of 6, and allow it to change
  to a 1 if adj is used.
*/

static INDEX bib1_indexes[] =
{
/* { "KEYNAME", 0, use, relation=0, position=num?2:3, structure,
                truncation=0, completeness=0}, Full Name */
    {"PERS_NAME",       "", 0,  1, 0, 3, 6, 0, 0},      /* personal name */
    {"AUTHOR_PN",       "", 0,  1, 0, 3, 6, 0, 0},      /* backward compatible */
    {"PERS_NAME_WP",    "", 0,  1, 0, 3, 1, 0, 0},      /* word phrase */
    {"PAP",             "", 0,  1, 0, 3, 1, 0, 0},      /* backward compatible */
    {"CORPORATION",     "", 0,  2, 0, 3, 6, 0, 0},      /* corporate name */
    {"ORGANIZATION",    "", 0,  2, 0, 3, 6, 0, 0},      /* backwards comp. */
    {"CAP",             "", 0,  2, 0, 3, 1, 0, 0},      /* backward comp. */
    {"CORPORATION_WP",  "", 0,  2, 0, 3, 1, 0, 0},      /* corporate name word phrase */
    {"CONFERENCE",      "", 0,  3, 0, 3, 6, 0, 0},      /* conference name */
    {"CONFERENCE_WP",   "", 0,  3, 0, 3, 1, 0, 0},      /* conference word phrase */
    {"TITLE",           "", 0,  4, 0, 3, 6, 0, 0},      /* title */
    {"TITLE_WP",        "", 0,  4, 0, 3, 1, 0, 0},      /* title word phrase */
    {"TWP",             "", 0,  4, 0, 3, 1, 0, 0},      /* backward comp. */
    {"SERIES",          "", 0,  5, 0, 3, 6, 0, 0},      /* title series */
    {"SERIES_WP",       "", 0,  5, 0, 3, 1, 0, 0},      /* series word phrase */
    {"UNFRM_TITLE",     "", 0,  6, 0, 3, 6, 0, 0},      /* title uniform */
    {"UNFRM_TITLE_WP",  "", 0,  6, 0, 3, 1, 0, 0},      /* title uniform word phrase */
    {"ISBN",            "", 0,  7, 0, 2, 2, 0, 0},      /* ISBN */
    {"ISSN",            "", 0,  8, 0, 2, 2, 0, 0},      /* ISSN */
    {"LCCN",            "", 0,  9, 0, 2, 2, 0, 0},      /* LC control num */
    {"BNBN",            "", 0, 10, 0, 2, 2, 0, 0},      /* BNB card number */
    {"BGFN",            "", 0, 11, 0, 2, 2, 0, 0},      /* BGF number */
    {"LOCAL_NUM",       "", 0, 12, 0, 2, 2, 0, 0},      /* Local number */
    {"DEWEY_NUM",       "", 0, 13, 0, 2, 2, 0, 0},      /* Dewey call num */
    {"UDC_NUM",         "", 0, 14, 0, 2, 2, 0, 0},      /* UDC clssfctn */
    {"BLISS_NUM",       "", 0, 15, 0, 2, 2, 0, 0},      /* Bliss clssfctn */
    {"LC_CALL",         "", 0, 16, 0, 2, 2, 0, 0},      /* LC call number */
    {"NLM_CALL",        "", 0, 17, 0, 2, 2, 0, 0},      /* NLM call number */
    {"NAL_CALL",        "", 0, 18, 0, 2, 2, 0, 0},      /* NAL call number */
    {"MOS_CALL",        "", 0, 19, 0, 2, 2, 0, 0},      /* MOS call number */
    {"LOCAL_CALL",      "", 0, 20, 0, 2, 2, 0, 0},      /* Local clssfctn */
    {"SUBJECT",         "", 0, 21, 0, 3, 6, 0, 0},      /* Subject heading */
    {"SUBJECT_WP",      "", 0, 21, 0, 3, 1, 0, 0},      /* Subject word phrase */
    {"SP",              "", 0, 21, 0, 3, 1, 0, 0},      /* backward comp. */
    {"RAMEAU_SUBJ",     "", 0, 22, 0, 3, 6, 0, 0},      /* Subject Rameau */
    {"RAMEAU_SUBJ_WP",  "", 0, 22, 0, 3, 1, 0, 0},      /* Subject Rameau word phrase */
    {"BDI_SUBJ",        "", 0, 23, 0, 3, 6, 0, 0},      /* BDI index subj */
    {"BDI_SUBJ_WP",     "", 0, 23, 0, 3, 1, 0, 0},      /* BDI index subj word phrase */
    {"INSPEC_SUBJ",     "", 0, 24, 0, 3, 6, 0, 0},      /* INSPEC subject */
    {"INSPEC_SUBJ_WP",  "", 0, 24, 0, 3, 1, 0, 0},      /* INSPEC subject word phrase */
    {"MESH_SUBJ",       "", 0, 25, 0, 3, 6, 0, 0},      /* MESH subj head */
    {"MESH_SUBJ_WP",    "", 0, 25, 0, 3, 1, 0, 0},      /* MESH subj head word phrase */
    {"PA_SUBJ",         "", 0, 26, 0, 3, 6, 0, 0},      /* subject */
    {"PA_SUBJ_WP",      "", 0, 26, 0, 3, 1, 0, 0},      /* subject word phrase */
    {"LC_SUBJ",         "", 0, 27, 0, 3, 6, 0, 0},      /* LC subj head */
    {"LC_SUBJ_WP",      "", 0, 27, 0, 3, 1, 0, 0},      /* LC subj head word phrase */
    {"RVM_SUBJ",        "", 0, 28, 0, 3, 6, 0, 0},      /* RVM subj head */
    {"RVM_SUBJ_WP",     "", 0, 28, 0, 3, 1, 0, 0},      /* RVM subj head word phrase */
    {"LOCAL_SUBJ",      "", 0, 29, 0, 3, 6, 0, 0},      /* Local subj idx */
    {"LOCAL_SUBJ_WP",   "", 0, 29, 0, 3, 1, 0, 0},      /* Local subj idx word phrase */
    {"DATE",            "", 0, 30, 0, 3, 6, 0, 0},      /* Date */
    {"PUBDATE",         "", 0, 31, 0, 3, 6, 0, 0},      /* pub Date */
    {"ACQ_DATE",        "", 0, 32, 0, 3, 6, 0, 0},      /* acq Date */
    {"KEY_TITLE",       "", 0, 33, 0, 3, 6, 0, 0},      /* Title key */
    {"KEY_TITLE_WP",    "", 0, 33, 0, 3, 1, 0, 0},      /* Title key word phrase */
    {"COLL_TITLE",      "", 0, 34, 0, 3, 6, 0, 0},      /* coll Title */
    {"COLL_TITLE_WP",   "", 0, 34, 0, 3, 1, 0, 0},      /* coll Title word phrase */
    {"PLL_TITLE",       "", 0, 35, 0, 3, 6, 0, 0},      /* parallel Title */
    {"PLL_TITLE_WP",    "", 0, 35, 0, 3, 1, 0, 0},      /* parallel Title word phrase */
    {"COVER_TITLE",     "", 0, 36, 0, 3, 6, 0, 0},      /* cover Title */
    {"COVER_TITLE_WP",  "", 0, 36, 0, 3, 1, 0, 0},      /* cover Title word phrase */
    {"TITLEPAGE",       "", 0, 37, 0, 3, 6, 0, 0},      /* add Ttl ttl pg */
    {"TITLEPAGE_WP",    "", 0, 37, 0, 3, 1, 0, 0},      /* add Ttl ttl pg word phrase */
    {"CAPT_TITLE",      "", 0, 38, 0, 3, 6, 0, 0},      /* caption Title */
    {"CAPT_TITLE_WP",   "", 0, 38, 0, 3, 1, 0, 0},      /* caption Title word phrase */
    {"RUN_TITLE",       "", 0, 39, 0, 3, 6, 0, 0},      /* running Title */
    {"RUN_TITLE_WP",    "", 0, 39, 0, 3, 1, 0, 0},      /* running Title word phrase */
    {"SPINE_TITLE",     "", 0, 40, 0, 3, 6, 0, 0},      /* spine Title */
    {"SPINE_TITLE_WP",  "", 0, 40, 0, 3, 1, 0, 0},      /* spine Title word phrase */
    {"OVAR_TITLE",      "", 0, 41, 0, 3, 6, 0, 0},      /* other var Title */
    {"OVAR_TITLE_WP",   "", 0, 41, 0, 3, 1, 0, 0},      /* other var Title word phrase */
    {"FORMER_TITLE",    "", 0, 42, 0, 3, 6, 0, 0},      /* former Title */
    {"FORMER_TITLE_WP", "", 0, 42, 0, 3, 1, 0, 0},      /* former Title word phrase */
    {"ABBR_TITLE",      "", 0, 43, 0, 3, 6, 0, 0},      /* abbr Title */
    {"ABBR_TITLE_WP",   "", 0, 43, 0, 3, 1, 0, 0},      /* abbr Title word phrase */
    {"EXPN_TITLE",      "", 0, 44, 0, 3, 6, 0, 0},      /* expn Title */
    {"EXPN_TITLE_WP",   "", 0, 44, 0, 3, 1, 0, 0},      /* expn Title word phrase */
    {"PRECIS_SUBJ",     "", 0, 45, 0, 3, 6, 0, 0},      /* precis Subj */
    {"PRECIS_SUBJ_WP",  "", 0, 45, 0, 3, 1, 0, 0},      /* precis Subj */
    {"RSWK_SUBJ",       "", 0, 46, 0, 3, 6, 0, 0},      /* rswk Subject */
    {"RSWK_SUBJ_WP",    "", 0, 46, 0, 3, 1, 0, 0},      /* rswk Subject word phrase */
    {"SUBDIV_SUBJ",     "", 0, 47, 0, 3, 6, 0, 0},      /* subdiv Subj */
    {"SUBDIV_SUBJ_WP",  "", 0, 47, 0, 3, 1, 0, 0},      /* subdiv Subj  word phrase */
    {"NATBIB_NUM",      "", 0, 48, 0, 3, 6, 0, 0},      /* nat bib Num */
    {"NATBIB_NUM_WP",   "", 0, 48, 0, 3, 1, 0, 0},      /* nat bib Num word phrase */
    {"LGLDEP_NUM",      "", 0, 49, 0, 3, 6, 0, 0},      /* legal deposit */
    {"LGLDEP_NUM_WP",   "", 0, 49, 0, 3, 1, 0, 0},      /* legal deposit word phrase */
    {"GOVTPUB_NUM",     "", 0, 50, 0, 3, 6, 0, 0},      /* govt pub Num */
    {"GOVTPUB_NUM_WP",  "", 0, 50, 0, 3, 1, 0, 0},      /* govt pub Num word phrase */
    {"MUSIC_PUB",       "", 0, 51, 0, 3, 6, 0, 0},      /* music pub Num */
    {"MUSIC_PUB_WP",    "", 0, 51, 0, 3, 1, 0, 0},      /* music pub Num word phrase */
    {"DB_NUM",          "", 0, 52, 0, 3, 6, 0, 0},      /* db Num */
    {"DB_NUM_WP",       "", 0, 52, 0, 3, 1, 0, 0},      /* db Num word phrase*/
    {"LOCAL_ID",        "", 0, 53, 0, 3, 6, 0, 0},      /* local shelf loc */
    {"LOCAL_ID_WP",     "", 0, 53, 0, 3, 1, 0, 0},      /* local shelf loc word phrase */
    {"LANGUAGE",        "", 0, 54, 0, 3, 6, 0, 0},      /*language Code */
    {"GEO_CODE",        "", 0, 55, 0, 3, 6, 0, 0},      /* Code geo area */
    {"INST_CODE",       "", 0, 56, 0, 3, 6, 0, 0},      /* Code institution */
    {"NAME_TITLE",      "", 0, 57, 0, 3, 6, 0, 0},      /*Name and title */
    {"NAME_TITLE_WP",   "", 0, 57, 0, 3, 1, 0, 0},      /*Name and title  word phrase */
    {"GEO_NAME",        "", 0, 58, 0, 3, 6, 0, 0},      /* geographic Name */
    {"GEO_NAME_WP",     "", 0, 58, 0, 3, 1, 0, 0},      /* geographic Name word phrase */
    {"PUB_PLACE",       "", 0, 59, 0, 3, 6, 0, 0},      /* publication Place */
    {"PUB_PLACE_WP",    "", 0, 59, 0, 3, 1, 0, 0},      /* publication Place word phrase */
    {"CODEN",           "", 0, 60, 0, 2, 2, 0, 0},      /* CODEN */
    {"MFORM_GEN",       "", 0, 61, 0, 3, 6, 0, 0},      /* microform generation */
    {"ABSTRACT",        "", 0, 62, 0, 3, 6, 0, 0},      /* Abstract */
    {"ABSTRACT_WP",     "", 0, 62, 0, 3, 1, 0, 0},      /* Abstract word phrase */
    {"NOTE",            "", 0, 63, 0, 3, 6, 0, 0},      /* Note */
    {"NOTE_WP",         "", 0, 63, 0, 3, 1, 0, 0},      /* Note word phrase*/
    {"AUTHOR_TITLE",    "", 0, 1000, 0, 3, 6, 0, 0},    /* author-title */
    {"AUTHOR_TITLE_WP", "", 0, 1000, 0, 3, 1 ,0, 0},    /* author-title */
    {"RECTYPE",         "", 0, 1001, 0, 3, 6, 0, 0},    /*  Record type */
    {"RECTYPE_WP",      "", 0, 1001, 0, 3, 1, 0, 0},    /*  Record type word phrase */
    {"NAME",            "", 0, 1002, 0, 3, 6, 0, 0},    /* Name */
    {"NAME_WP",         "", 0, 1002, 0, 3, 1, 0, 0},    /* Name word phrase */
    {"AUTHOR",          "", 0, 1003, 0, 3, 6, 0, 0},    /* Author */
    {"AUTHOR_WP",       "", 0, 1003, 0, 3, 1, 0, 0},    /* Author word phrase */
    {"PERS_AUTHOR",     "", 0, 1004, 0, 3, 6, 0, 0},    /* personal Author-name */
    {"PERS_AUTHOR_WP",  "", 0, 1004, 0, 3, 1, 0, 0},    /* personal Author-name word phrase */
    {"CORP_AUTHOR",     "", 0, 1005, 0, 3, 6, 0, 0},    /* corporate Author-name */
    {"CORP_AUTHOR_WP",  "", 0, 1005, 0, 3, 1, 0, 0},    /* corporate Author-name word phrase */
    {"CONF_AUTHOR",     "", 0, 1006, 0, 3, 6, 0, 0},    /* Author-name conference */
    {"CONF_AUTHOR_WP",  "", 0, 1006, 0, 3, 1, 0, 0},    /* Author-name word phrase conference */
    {"STANDARD_ID",     "", 0, 1007, 0, 3, 6, 0, 0},    /* Identifier-standard */
    {"STANDARD_ID_WP",  "", 0, 1007, 0, 3, 1, 0, 0},    /* Identifier-standard word phrase */
    {"LC_CHILD_SUBJ",   "", 0, 1008, 0, 3, 6, 0, 0},    /*  Subject-LC children's */
    {"LC_CHILD_SUBJ_WP","", 0, 1008, 0, 3, 1, 0, 0},    /*  Subject-LC children's word phrase */
    {"PERSNAME_SUBJ",   "", 0, 1009, 0, 3, 6, 0, 0},    /*  Subject name-personal */
    {"PERSNAME_SUBJ_WP","", 0, 1009, 0, 3, 1, 0, 0},    /*  Subject name-personal word phrase */
    {"TEXT_BODY",       "", 0, 1010, 0, 3, 6, 0, 0},    /* Body of text */
    {"TEXT_BODY_WP",    "", 0, 1010, 0, 3, 1, 0, 0},    /* Body of text word phrase */
    {"DB_ADD_TIME",     "", 0, 1011, 0, 3, 6, 0, 0},    /* Date/time added to database */
    {"DB_ADD_TIME_WP",  "", 0, 1011, 0, 3, 1, 0, 0},    /* Date/time added to database word phrase */
    {"DB_MOD_TIME",     "", 0, 1012, 0, 3, 6, 0, 0},    /* Date/time last modified */
    {"DB_MOD_TIME_WP",  "", 0, 1012, 0, 3, 1, 0, 0},    /* Date/time last modified word phrase */
    {"ATY_FMT_ID",      "", 0, 1013, 0, 3, 6, 0, 0},    /* Authority and  format identifier */
    {"CONCEPT_TEXT",    "", 0, 1014, 0, 3, 6, 0, 0},    /*  Concept-text */
    {"CONCEPT_TEXT_WP", "", 0, 1014, 0, 3, 1, 0, 0},    /*  Concept-text word phrase */
    {"CONCEPT_REF",     "", 0, 1015, 0, 3, 6, 0, 0},    /* Concept-reference */
    {"CONCEPT_REF_WP",  "", 0, 1015, 0, 3, 1, 0, 0},    /* Concept-reference word phrase */
/* Note: Default went away and ANY became 1016 in v3d10
I chose not to change that just now -wdc */
    {"DEFAULT",         "", 0, 1016, 0, 3, 6, 0, 0},    /* default */
    {"DEFAULT_WP",      "", 0, 1016, 0, 3, 1, 0, 0},    /* word phrase default */
    {"ANY",             "", 0, 1017, 0, 3, 6, 0, 0},    /* any */
    {"ANY_WP",          "", 0, 1017, 0, 3, 1, 0, 0},
    {"SERVER_CHOICE",   "", 0, 1017, 0, 3, 6, 0, 0},    /* any */
    {"SERVER_CHOICE_WP","", 0, 1017, 0, 3, 1, 0, 0},    /* word phrase */
    {"PUBLISHER",       "", 0, 1018, 0, 3, 6, 0, 0},
    {"RECORD_SOURCE",   "", 0, 1019, 0, 3, 1, 0, 0},
    {"EDITOR",          "", 0, 1020, 0, 3, 6, 0, 0},
    {"BIB_LEVEL",       "", 0, 1021, 0, 3, 6, 0, 0},
    {"GEO_CLASS",       "", 0, 1022, 0, 3, 6, 0, 0},    /* Geographical Class */
    {"INDEXED_BY",      "", 0, 1023, 0, 3, 6, 0, 0},
    {"MAP_SCALE",       "", 0, 1024, 0, 3, 6, 0, 0},
    {"MUSIC_KEY",       "", 0, 1025, 0, 3, 6, 0, 0},
    {"REL_PERIODICAL",  "", 0, 1026, 0, 3, 6, 0, 0},  /* Related Periodical */
    {"REPORT_NUMBER",   "", 0, 1027, 0, 3, 6, 0, 0},
    {"STOCK_NUMBER",    "", 0, 1028, 0, 3, 6, 0, 0},
    {"THEMATIC_NUMBER", "", 0, 1030, 0, 3, 6, 0, 0},
    {"MATERIAL_TYPE",   "", 0, 1031, 0, 3, 6, 0, 0},
    {"DOC_ID",          "", 0, 1032, 0, 3, 6, 0, 0},
    {"HOST_ITEM",       "", 0, 1033, 0, 3, 1, 0, 0},     /* Journal Title */
    {"CONTENT_TYPE",    "", 0, 1034, 0, 3, 6, 0, 0}      /* Publication Type - Editorial Review */
};

#endif /* MARKER */

#define bib1_total ((int) (sizeof(bib1_indexes) / sizeof(bib1_indexes[0])))

#endif
