/*
 *      CANCEL.C
 *
 * Served as the basis of the Z39.50 API's more
 * general trigger resource control code.
 */

#include <constant.h>
#include <msg.h>
#include <pdutags.h>
#include <putget.h>
#include <recinfo.h>
#include <session.h>
#include <z3950.h>

int send_search_cancel_pdu(SESSION *session)
/* Sends a trigger resource control request, requesting a cancel.
   We assume there won't be a response, and that
  the code that handles Resource Control will do the
  right thing.
  These semantics differ from the API's
  send_trigger_control_pdu in the following ways:
  1. We check and make sure we're ALLOWED to send a
     search cancel.
  2. We expect the caller to do the right thing if
     we return NOTOK, which signifies we're not allowed.
  3. We don't wait for a response, because the search
     is already waiting for the response.
*/
{
    extern int debug_level;

    RECORD_INFO *info;

    if ((MAX_OPTIONS > OPT_TRIGGER) &&
        ((session->option[OPT_TRIGGER] == '1') ||
         (session->option[OPT_TRIGGER] == 'y'))) {

        info = recinfo_new();
        Encode_TriggerResourceControl_Request(session, TRIG_CANCEL, 0l);
        if (MSG_TEST == OK) {
            if (debug_level) {
                fprintf(stderr,"Driver sent Trigger resource control Cancel\n");
                fflush(stderr);
            }
            transmit_pdu(session,
                         session->pdu,
                         TriggerResourceControlRequest,
                         0);
        }
        recinfo_dispose(&info);
        return MSG_TEST;
    } else return NOTOK;
}
