/*                           DATABASE.H                            */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#ifndef DATABASE_H
#define DATABASE_H

#ifndef ATTRCONS_H
#include "attrcons.h"
#endif

#define MAX_NAME_SIZE     32        /* Maximum size of index name */
#define EXTRA_INDEXES      5        /* Extra number of indexes to allocate */

/* Types of database queries */

#define RPN               1         /* Reverse Polish Notation */

typedef struct index_description
    {
        char name[MAX_NAME_SIZE];
        char filter[MAX_NAME_SIZE];
        int  attributes[MAX_ATTRIBUTES];
    } INDEX, *INDEX_REFERENCE;

typedef struct database_description
    {
        char    name[MAX_NAME_SIZE];		/* Name of database */
        char    *attribute_id;			/* Attributes OID */
        int     type;				/* Type of index */
	int     alloc_indexes;			/* Allocated indexes */
        int     total_indexes;			/* Total indexes */
        INDEX_REFERENCE indexes;
    } DATABASE, *DATABASE_REFERENCE;

#define NULL_INDEX                ((INDEX_REFERENCE) NULL)
#define NULL_DATABASE             ((DATABASE_REFERENCE) NULL)

/* Routine prototypes */

#define index_attributes(index)    ((int *) &index->attributes)
#define index_filter(index)        ((char *) index->filter)

#define database_name(db)    ((char *) &db->name)
#define database_free(db)    (free(db))

#define database_attribute_id(db)   ((char *) db->attribute_id)
#define database_query_type(db)     ((int) db->type)

INDEX_REFERENCE database_index(DATABASE_REFERENCE db,
                               char *name,
                               int  length);

DATABASE_REFERENCE database_new(char *name);

int database_set_index(DATABASE_REFERENCE db,
                       char  *attributes_id,
                       int   type,
                       INDEX_REFERENCE indexes,
                       int   total);

int database_new_index(DATABASE_REFERENCE db,
                       char  *name,
                       char  *attribute_list);

int database_show_index(DATABASE_REFERENCE db);

int database_dispose(DATABASE_REFERENCE *db);

#endif
