/*
 *      mdisplay.c -- display records in TOMAS "marc" format
 *
 *      Philip L. Budne, Boston University, Distributed Systems Group
 *      Copyright 1988, 1989, Philip L. Budne
 *      May be used in not-for-profit applications provided this
 *      notice and the above copyright are not removed.  No warranty
 *      is expressed or implied.
 */

# include <stdio.h>                     /* get standard i/o library defns */
# include "oclc.h"                      /* get our defns */

static int record_count;

void
pdata( dp, len )                        /* print data */
    char *dp;
    int len;
{
    while( len-- > 0 ) {
        char c;

        c = *dp++;                      /* get next character */

        if( c == RS )                   /* field terminator? (RS) */
            break;                      /* break loop */

        if( c == US ) {                 /* subfield delim (doub dag) (US) */
            len--;                      /* account for subsection letter */
            if( len < 0 )               /* no more data? */
                lose("bad subfield");   /* quit. */

            /* print next char too (sub section letter) */
            printf(" %c%c ", c, *dp++); /* dont' use putchar(*dp++); */
                                        /* as putchar is a macro!! */
            continue;                   /* continue printing data */
        } /* found US */

        if( c >= ' ' && c <= '~' )      /* printing ascii? */
            putchar( c );               /* just copy to stdout */
# ifdef DISPLAY_DIACRITICS
        else
            printf("<%02x>", c & 0xff); /* print hex code. */
                                        /* interpret? (output troff?) */
# endif /* DISPLAY_DIACRITICS defined */
    } /* while */
} /* pdata */

void display( code, record, offset, length )
    int code, offset, length;
    char *record;
{
    /* Process 001...009 */
/* 
    if( code < 10 ) {
        process( code, record, offset, length );
        return;
    }
    else if( record_count == 0 )
        dump_header_info();
*/
    record_count++;
/*  printf("%3d %03d ", record_count, code ); */
    printf("%03d ", code );
    pdata( record+offset, length );     /* give pointer to data */
    putchar('\n');                      /* output newline char */

} /* display */

void end_record() {
} /* end */

/****************************************************************/

static long oclc_id;

void start_record() {
    record_count = 0;
    oclc_id = -1;
} /* start */

static
void dump_header_info() {
    if( oclc_id != -1 )
        printf("OCLC: %8d\n", oclc_id );
}

static
void process( code, record, offset, length )
    int code, offset, length;
    char *record;
{
    char bib_lvl;

    switch( code ) {
    case 1:                             /* careful!! 001 is octal! */
/*
        if( record[offset] != 'o' || record[offset+1] != 'c' ||
           record[offset+2] != 'm' )
            lose( "Bad info in cols 0-2 of 001 record" );
*/
        oclc_id = getint( record+offset+3, 8 );
        break;

    case 8:
        /* check record[7] (bib level) for interpretation!? */
        bib_lvl = record[7];

    } /* switch on code */
} /* process */
