/*
 *      ndisplay.c -- display records in "normal" format (TOMAS D/DN)
 *
 *      Philip L. Budne, Boston University, Distributed Systems Group
 *      Copyright 1988, 1989, Philip L. Budne
 *      May be used in not-for-profit applications provided this
 *      notice and the above copyright are not removed.  No warranty
 *      is expressed or implied.
 *
 */

# include <stdio.h>                     /* get standard i/o library defns */
# include "oclc.h"                      /* get our defns */

void
copy( dp, sp, len )
    register char *dp, *sp;
    register len;
{
    while( len-- > 0 ) {
        register c;

        c = *sp++;                      /* get next character */
        if( c == RS )                   /* field terminator? (RS) */
            break;                      /* break loop */
        else if( c == US ) {            /* subfield delim (doub dag) (US) */
            len--;                      /* account for subsection letter */
            if( len < 0 )               /* no more data? */
                lose("bad subfield");   /* quit. */

            sp++;                       /* toss section letter */
            *dp++ = ' ';                /* insert space */

        } /* found US */
        else if( c >= ' ' && c <= '~' ) /* printing ascii? */
            *dp++ = c;
    } /* while */
    *dp = EOS;
} /* copy */

/****************************************************************/

typedef char str[ 1024 ];
str auth, title, publ, descr, notes, subj, other, loc, call;
int authtype, titletype, publtype, descrtype, notestype,
    subjtype, othertype, loctype,  calltype;

start_record() {
    authtype = titletype = publtype = descrtype = notestype =
        subjtype = othertype = loctype = calltype = -1;
} /* start */

end_record() {
    int n;

# define MUMBLE(data,type,name) \
    if( type != -1 ) { printf("%-16s %s\n", name, data ); n++; }

    n = 0;
    MUMBLE(auth, authtype,  "AUTHOR" );
    MUMBLE(title,titletype, "TITLE" );
    MUMBLE(publ, publtype,  "PUBLICATION" );
    MUMBLE(descr,descrtype, "DESCRIPTION" );
    MUMBLE(notes,notestype, "NOTES" );          /* NEVER SET! */
    MUMBLE(subj, subjtype,  "SUBJECTS" );       /* NEVER SET! */
    MUMBLE(other,othertype, "OTHER" );          /* NEVER SET! */
    MUMBLE(loc,  loctype,   "LOCATION" );       /* need to expand! */
    MUMBLE(call, calltype,  "CALL NUMBER" );    /* clean up? */
} /* end */

display( code, record, offset, length )
    int code, offset, length;
    char *record;
{
    char bib_lvl;

    record += offset+2;                         /* skip 2 indicators */

    /* MUST PRIORITIZE MULTIPLE RECORD TYPES */

    switch( code ) {
    case 49:
        if( loctype != -1 )
            puts("second location");
        copy( loc, record, length );
        loctype = code;
        break;

    case 50:
    case 90:
    case 99:
        if( calltype != -1 )
            printf("second call %03d (was %03d)\n", code, calltype );
        copy( call, record, length );
        calltype = code;
        break;


    case 100:
    case 110:
    case 130:
        if( authtype != -1 )
            printf("second author %03d (was %03d)\n", code, authtype );
        copy( auth, record, length );
        authtype = code;
        break;

    case 240:
    case 245:
        if( titletype != -1 )
            printf("second title %03d (was %03d)\n", code, titletype );
        copy( title, record, length );
        titletype = code;
        break;

    case 260:
        if( publtype != -1 )
            puts("second publication");
        copy( publ, record, length );
        publtype = code;
        break;

    case 300:
        if( descrtype != -1 )
            puts("second description");
        copy( descr, record, length );
        descrtype = code;
        break;

    } /* switch on code */
} /* process */
