/*                             OCLC.C                              */

/*
 *      oclc.c -- read oclc mark tape records
 *
 *      Philip L. Budne, Boston University, Distributed Systems Group
 *      Copyright 1988, 1989, Philip L. Budne
 *      May be used in not-for-profit applications provided this
 *      notice and the above copyright are not removed.  No warranty
 *      is expressed or implied.
 *
 *      Coded as per "OCLC-MARK Tape Format" ISBN: 0-933418-62-0
 *      1984, OCLC
 */

# include <stdio.h>                     /* get standard i/o library defns */
# include "oclc.h"                      /* get our defns */

extern FILE *out;

void lose(), holdings(), bibliographic(), pdata(); /* forward defn. */

int dmarc(position, record, llen)
    int position;
    char *record;
    int llen;
{
/*---------- To save records ---------------
        FILE *keep;
        keep = fopen("zrecords","ab");
        fwrite(record, llen, 1, keep);
        fclose(keep);
--------------------------------------------*/

        if( record[6] == 'y' )          /* check if a holdings record */
            holdings( record, llen );   /* it is???? */
        else
            bibliographic( record, llen );
} /* main */

void
lose(f, a, b, c )                       /* dangerous... should use varargs */
    char *f, *a, *b, *c;
{
    fprintf(out, "-DIAGNOSTIC: (0) ");
    fprintf(out, f, a, b, c );
    fputc('\n', out);
} /* lose */

void
holdings( record, llen )                /* print a holdings record */
    char *record;
    int llen;
{
    if( llen < MINH || llen > MAXH )
       lose("Warning! The length of the MARC holdings record is %d", llen);

    puts("holdings records nyi");       /* never seen one!! */
                                        /* (not fatal) */
} /* holdings */

void
bibliographic( record, llen )
    char *record;
    int llen;
{
    int baseaddr, p;
    int lensiz, offsiz;

    if( llen < MINB || llen > MAXB )
        lose("Warning! The length of the MARC bibliographic record is %d", llen);

    baseaddr = getint( record+12, 5 );  /* 12-16 base address */
    if( baseaddr < 24 || baseaddr > llen )
        lose("bad MARC base address %d (length %d)", baseaddr, llen );

# ifdef DISPLAY_LEADER
    pr_bib_fixed( record );             /* print fixed leader */
# endif /* DISPLAY_LEADER defined */

    start_record();


    /* Check the number of digits in the length of a field */

    lensiz = getint(record+20, 1);
    if( lensiz != 4 ) {
        lose("Unusual size of MARC field length (column 20): %d", lensiz);
        lensiz = 4;
    }

    /* Check the number of digits for a field offset */

    offsiz = getint(record+21, 1);
    if( offsiz != 5 ) {
        lose("Unusual size of MARC offset (column 21): %d", offsiz);
        offsiz = 5;
    }

    p = 24;                             /* data starts in column 24 */
    while( p < baseaddr && record[p] != RS ) {
        int code, offset, length;

# define CODELEN 3

        code = getint( record+p, CODELEN );
        p += CODELEN;

        length = getint( record+p, lensiz ); /* get length */
        p += lensiz;                    /* advance pointer */

        offset = getint( record+p, offsiz ); /* get offset */
        p += offsiz;                    /* advance pointer */

        /* baseaddr+offset is first char of data */
        /* baseaddr+offset+length-1 is last char of data */
        if( offset+baseaddr+length-1 > llen ) /* end of data */
            lose("data out of bounds"); /* past end of logical record?? */

        /****************************************************************
         * perform record type dependant processing here!!
         */
        display( code, record, offset+baseaddr, length );
        /*
         ****************************************************************/
    } /* while */
    end_record();
} /* bib record */

int
getint( cp, cc )                       
    register char *cp;                  /* pointer */
    register int cc;                    /* length */
{
    register c, i;

    i = 0;
    while( cc-- ) {
        c = *cp++;
        if( c < '0' || c > '9' )
            lose("bad digit '%c'", c );
        i = (i * 10) + c - '0';
    } /* while */
    return( i );
} /* getint */

void pr_bib_fixed( record )                  /* print bib record fixed leader */
    char *record;
{
    switch( record[5] ) {               /* record status */
    case 'n':
        puts("new record");
        break;
    case 'c':
        puts("corrected record");
        break;
    case 'p':
        puts("previously prepublication record");
        break;
    case 'a':
        puts("increase in coding level");
        break;
    default:
        printf("** unknown bib rec stat '%c'\n", record[5] );
        break;
    } /* rec stat */

    printf("record type '%c'\n", record[6] );
    printf("bib level '%c'\n", record[7] );

    if( record[8] != ' ' || record[9] != ' ' ||
       record[10] != '2' || record[11] != '2' )
        lose("invalid contents in 8, 9, 10, or 11 of bib record");

    /* 12-16 base address */
    printf("encoding level '%c'\n", record[17] );
    printf("desc catalogging form '%c'\n", record[18] );
    /* 19 blank */
    /* 20, 21 size of length and offset */

    switch( (unsigned char) record[22] ) {              /* transaction type */
    case 0x01:
        puts("produce");
        break;
    case 0x02:
        puts("update");
        break;
    case 0x03:
        puts("cancel update");
        break;
    case 0x11:
        puts("replace");
        break;
    case 0x50:
        puts("all produce");
        break;
    case 0x90:
        puts("offline retrieve");
        break;
    case 0x92:
        puts("offline update");
        break;
    case 0x93:
        puts("offline cancel update");
        break;
    case 0x94:
        puts("microcon update");
        break;
    default:
        printf("bad transaction code %#02x\n", record[22] );
        break;
    } /* transaction code */

    /* 23 '0' */
} /* pr_bib_fixed */
