/*                            PDUTAGS.H                            */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#ifndef PDUTAGS_H
#define PDUTAGS_H

/* ASN.1 Universal field id's */

#define BOOLEAN       1
#define INTEGER       2
#define BITSTRING     3
#define OCTETSTRING   4
#define OBJECTID      6
#define EXTERNAL      8
#define REAL          9
#define ENUMBERATED   10
#define SEQUENCE      16
#define SET           17
#define VISIBLESTR    26
#define GENERALSTR    27

/*Tag Identifiers for IRP Command Parameters */

enum shared_global_tags
{
    PduType = 1,
    ReferenceId = 2,
    ResultSetId = 31,
    ElementSetName = 103,
    DatabaseName = 105,
    OtherInformation = 201
};

/*Tag Identifiers for IRP Commands */

enum irp_tags
{
    InitializeRequest = 20,
    InitializeResponse,
    SearchRequest,
    SearchResponse,
    PresentRequest,
    PresentResponse,
    DeleteResultSetRequest,
    DeleteResultSetResponse,
    AccessControlRequest,
    AccessControlResponse,
    ResourceControlRequest,
    ResourceControlResponse,
    TriggerResourceControlRequest,
    ResourceReportRequest,
    ResourceReportResponse,
    ScanRequest,
    ScanResponse,
    SortRequest = 43,
    SortResponse,
    SegmentRequest,
    ExtendedServicesRequest,
    ExtendedServicesResponse,
    Close
};

enum shared_search_and_present_tags
{
    NumberOfRecordsReturned = 24,      /* Response only */
    NextResultSetPosition,             /* Response only */
    PresentStatus = 27,                /* Response only */
    DatabaseOrDiagnosticRecords,       /* Response only */
    PreferredRecordSyntax = 104        /* Request  only */
};

enum search_request_tags
{
    SmallSetUpperBound = 13,
    LargeSetLowerBound,
    MediumSetPresentNumber,
    ReplaceIndicator,
    ResultSetName,
    DatabaseNames,
    SmallSetElementSetNames = 100,
    MediumSetElementSetNames,
/*  PreferredRecordSyntax = 104,       -- shared search and present tags -- */
    Query = 21
};

enum search_response_tags
{
    ResultCount = 23,
/*  NumberOfRecordsReturned = 24,      -- shared search and present tags -- */
/*  NextResultSetPosition,             -- shared search and present tags -- */
    SearchStatus = 22,
    ResultSetStatus = 26
/*  PresentStatus = 27,                -- shared search and present tags -- */
/*  DatabaseOrDiagnosticRecords,       -- shared search and present tags -- */
};

enum present_request_tags
{
/*  ResultSetId = 31,                  -- shared global tags -- */
    NumberOfRecordsRequested = 29,
    ResultSetStartPoint
/*  PreferredRecordSyntax = 104,       -- shared search and present tags -- */
};

/* -- Search response only uses shared tags --
enum search_response_tags
{
    NumberOfRecordsReturned = 24,      -- shared search and present tags --
    NextResultSetPosition,             -- shared search and present tags --
    PresentStatus = 27,                -- shared search and present tags --
    DatabaseOrDiagnosticRecords        -- shared search and present tags --
};
 * -- */

enum query_tags
{
    Operand = 0,
    RPNQuery = 1,
    RPNStructure = 1,
    AttributeList = 44,
    Term,
    Operator,
    AttributesPlusTerm = 102,
    AttributeType = 120,
    AttributeValue
};

enum record_tags
{
    NPR_DatabaseName = 0,
    NPR_Choice = 1,
    NPR_DatabaseRecord = 1,
    NPR_DiagnosticRecord = 2,
    DatabaseOrSurDiagnostics = 28,
    NonSurrogateDiagnostic = 130
};

enum estimate_tags
{
    EstimateType = 1,
    EstimateValue
};

enum external_tags
{
    ExternalEncodedType = 0,
    ExternalEncodedOctet,
    ExternalEncodedArbitrary
};

enum otherinfo_tags
{
    Category = 1,
    CategoryTypeId = 1,
    CharacterInfo = 2,
    CategoryValue = 2,
    BinaryInfo = 3,
    ExternallyDefinedInfo
};

#endif    /* PDUTAGS_H */
