/*                             PLACE.C                             */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 *
 *  Common routines to place and extract information from
 *  a pdu.
 */

#include "constant.h"
#include "database.h"
#include "msg.h"
#include "putget.h"
#include "pdutags.h"
#include "record.h"

enum element_set_name_tags
{
    Generic = 0,
    DatabaseSpecific,
    ElementSetNames = 19
/*  ElementSetName = 103,         -- shared global tags -- */
/*  DatabaseName   = 105,         -- shared global tags -- */
};
   
/*--------------------------------------------------------------*
 |                  PLACE_DB_ELEMENT_SET_NAMES                  |
 | Function:                                                    |
 |    Encode the ASN.1 Element Set Names.                       |
 | Parameters:                                                  |
 |    node       : Pointer to node to add element set names.    |
 |    generic    : C string to the generic element set name.    |
 |    db         : Pointer to the database information.         |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

void place_db_element_set_names(DATA_DIR *node,
                                char *generic,
                                DATABASE_REFERENCE db)
{
/************ Ignore until multiple databases **********

    PDbSpecific = put_node(node, DatabaseSpecific, ASN1_CONTEXT);
    if (PDbSpecific != NULL)
        {
            int = i;

            for (i = 1; i <= database_count(db); i++)
                {
                    DATA_DIR *sequence;

                    sequence = put_node(PDbSpecific, SEQUENCE, ASN1_UNIVERSAL);

                    if (sequence == NULL) break;

                    put_cstring(sequence, DatabaseName, database_name(db));

                    if (database_elemset(db) == NULL)
                        put_cstring(sequence, ElementSetName, generic);
                    else
                        put_cstring(sequence, ElementSetName, database_elemset(db));

                }
        }
*************************************/
}
 
/*--------------------------------------------------------------*
 |                  PLACE_ELEMENT_SET_NAMES                     |
 | Function:                                                    |
 |    Encode the ASN.1 Element Set Names.                       |
 | Parameters:                                                  |
 |    node       : Pointer to node to add element set names.    |
 |    generic    : C string to the generic element set name.    |
 |    db         : Pointer to the database information.         |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

void place_element_set_names(DATA_DIR *node,
                             char *generic,
                             DATABASE_REFERENCE db)
{
    DATA_DIR *PElemset;

    /* If no generic record syntax specified then ignore */

    if (generic == NULL || generic[0] == EOS)
        return;

    /* Also use "F" for generic full record if nothing specified */
    /* But it has problems when using a different preferred      */
    /* record syntax.                                            */
    /*  generic = "F";                                           */

    PElemset = put_node(node, ElementSetNames, ASN1_CONTEXT);

    if (PElemset != NULL)
        {
            /* Should check for Database Specific names */

        /* if (place_db_element_set_names(PElemset, generic, db) == 0) */
               put_cstring(PElemset, Generic, generic);
        }
}


/*--------------------------------------------------------------*
 |                  PLACE_PREFERRED_SYNTAX                      |
 | Function:                                                    |
 |    Encode the ASN.1 Preferred Record Syntax                  |
 | Parameters:                                                  |
 |    node       : Pointer to node to add element set names.    |
 |    syntax     : C string to the preferred record syntax      |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

void place_preferred_record_syntax(DATA_DIR *node,
				   unsigned int syntax)
{
    char *oid;

    oid = record_oid_from_syntax(syntax);

    if (*oid == ' ')
	msg_make(BAD_PREFERRED_SYNTAX, "(unknown)");
    else if (*oid != EOS)
        put_oid(node, PreferredRecordSyntax, oid); 
}
