/*                         PORTINFO.C                              */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 *
 *  Some operating systems are not very complient to ANSI-C
 *  and are missing some routines defined in the standard.
 *
 */

#include <errno.h>
#include <stdarg.h>
#include <stdio.h>

#include "portinfo.h"

/*
 * No object deck would be produced for systems which already
 * have these routines (which would cause make to fail) so the
 * following static variable forces an object deck to be produced.
 */

#ifdef DEFINE_STRERROR

/*--------------------------------------------------------------*
 |                    STRERROR                                  |
 | Function:                                                    |
 |    Uses the error number to find the system error message.   |
 | Parameters:                                                  |
 |    error   : The number of the error message.                |
 | Returns:                                                     |
 |    Pointer to the string containing the error message.       |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |    Do not modify the string returned.                        |
 |                                                              |
 |    This routine may not be defined for some ANSI-C           |
 |    implementations (in particular GNU).                      |
 *--------------------------------------------------------------*/

char *strerror(int error)
{
    static char *unknown_error = "Unknown error (%d)\n";
    static char error_message[30];
    extern char *sys_errlist[];
    extern int  sys_nerr;

    if (error >= 0 && error <= sys_nerr)
        return(sys_errlist[error]);

    sprintf(error_message, unknown_error, error);
    return(error_message);
}

#endif

#ifdef DEFINE_VSPRINTF

/*--------------------------------------------------------------*
 |                    VSPRINTF                                  |
 | Function:                                                    |
 |    Same as sprintf() except for single arguement list.       |
 | Parameters:                                                  |
 |    string  : Pointer to place formatted string.              |
 |    format  : Pointer to string of format.                    |
 |    args    : The variable argument list from va_start()      |
 | Returns:                                                     |
 |    The length of the formatted string.                       |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |    This routine may not be defined for some ANSI-C           |
 |    implementations.                                          |
 *--------------------------------------------------------------*/

int vsprintf(char *string,
             char *fmt,
             va_list args)
{
    struct _iobuf iob;

#ifdef pyr
    bzero ((char *) &iob, sizeof iob);
    iob._file = _NFILE;
#endif
    iob._flag = _IOWRT | _IOSTRG;
#if     !defined(vax) && !defined(pyr)
    iob._ptr = (unsigned char *) string;
#else
    iob._ptr = string;
#endif
    iob._cnt = BUFSIZ;
    _doprnt(fmt, args, &iob);
    putc(NULL, &iob);
    return strlen(string);
}

#endif

#ifdef DEFINE_STRTOL
/*-
 * Copyright (c) 1990 The Regents of the University of California.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    This product includes software developed by the University of
 *    California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
#if defined(LIBC_SCCS) && !defined(lint)
static char sccsid[] = "@(#)strtol.c  5.4 (Berkeley) 2/23/91";
#endif /* LIBC_SCCS and not lint */
#ifndef DEFINE_LIMITS
#include <limits.h>
#else
#define INT_MAX               2147483547      /* Maximum "int" decimal value */
#define INT_MIN               (-INT_MAX -1)   /* min decimal value of an "int" */
#define       LONG_MIN        INT_MIN         /* min decimal value of a "long" */
#define       LONG_MAX        INT_MAX         /* max decimal value of a "long" */
#endif
/*
 * Convert a string to a long integer.
 *
 * Ignores `locale' stuff.  Assumes that the upper and lower case
 * alphabets and digits are each contiguous.
 */
long
strtol(nptr, endptr, base)
      char *nptr;
      char **endptr;
      register int base;
{
      register char *s = nptr;
      register unsigned long acc;
      register int c;
      register unsigned long cutoff;
      register int neg = 0, any, cutlim;
      /*
       * Skip white space and pick up leading +/- sign if any.
       * If base is 0, allow 0x for hex and 0 for octal, else
       * assume decimal; if base is already 16, allow 0x.
       */
      do {
              c = *s++;
      } while (isspace(c));
      if (c == '-') {
              neg = 1;
              c = *s++;
      } else if (c == '+')
              c = *s++;
      if ((base == 0 || base == 16) &&
          c == '0' && (*s == 'x' || *s == 'X')) {
              c = s[1];
              s += 2;
              base = 16;
      }
      if (base == 0)
              base = c == '0' ? 8 : 10;
      /*
       * Compute the cutoff value between legal numbers and illegal
       * numbers.  That is the largest legal value, divided by the
       * base.  An input number that is greater than this value, if
       * followed by a legal input character, is too big.  One that
       * is equal to this value may be valid or not; the limit
       * between valid and invalid numbers is then based on the last
       * digit.  For instance, if the range for longs is
       * [-2147483648..2147483647] and the input base is 10,
       * cutoff will be set to 214748364 and cutlim to either
       * 7 (neg==0) or 8 (neg==1), meaning that if we have accumulated
       * a value > 214748364, or equal but the next digit is > 7 (or 8),
       * the number is too big, and we will return a range error.
       *
       * Set any if any `digits' consumed; make it negative to indicate
       * overflow.
       */
      cutoff = neg ? -(unsigned long)LONG_MIN : LONG_MAX;
      cutlim = cutoff % (unsigned long)base;
      cutoff /= (unsigned long)base;
      for (acc = 0, any = 0;; c = *s++) {
              if (isdigit(c))
                      c -= '0';
              else if (isalpha(c))
                      c -= isupper(c) ? 'A' - 10 : 'a' - 10;
              else
                      break;
              if (c >= base)
                      break;
              if (any < 0 || acc > cutoff || acc == cutoff && c > cutlim)
                      any = -1;
              else {
                      any = 1;
                      acc *= base;
                      acc += c;
              }
      }
      if (any < 0) {
              acc = neg ? LONG_MIN : LONG_MAX;
              errno = ERANGE;
      } else if (neg)
              acc = -acc;
      if (endptr != 0)
              *endptr = any ? s - 1 : (char *)nptr;
      return (acc);
}
#endif

#ifdef DEFINE_MKTIME

/*
 * mktime.c
 * Original Author:     G. Haley
 *
 * Taken from cygnus library. VAX doesn't have it.
 *
 * Converts the broken-down time, expressed as local time, in the structure
 * pointed to by tim_p into a calendar time value. The original values of the
 * tm_wday and tm_yday fields of the structure are ignored, and the original
 * values of the other fields have no restrictions. On successful completion
 * the fields of the structure are set to represent the specified calendar
 * time. Returns the specified calendar time. If the calendar time can not be
 * represented, returns the value (time_t) -1.
 */

#define _SEC_IN_MINUTE 60
#define _SEC_IN_HOUR 3600
#define _SEC_IN_DAY 86400

#ifndef div_t
typedef struct
{
  int quot; /* quotient */
  int rem; /* remainder */
} div_t;
#endif

#ifndef INT_MIN
#define INT_MIN (-INT_MAX-1)
#define INT_MAX 2147483647
#endif

div_t div (int n, int d)
{
  div_t res;

  if (d)
    {
      res.quot = abs (n) / abs (d);
      res.rem = abs (n) % abs (d);

      if ((n < 0 && d > 0) || (n >= 0 && d < 0))
        res.quot = -res.quot;
      if (n < 0)
        res.rem = -res.rem;
    }
  else
    {
      if (n < 0)
        res.quot = INT_MIN;
      else
        res.quot = INT_MAX;

      res.rem = 0;
    }

  return res;
}

static int DAYS_IN_MONTH[12] =
{31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};

#define _DAYS_IN_MONTH(x) ((x == 1) ? days_in_feb : DAYS_IN_MONTH[x])

static int _DAYS_BEFORE_MONTH[12] =
{0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334};

#define _DAYS_IN_YEAR(year) (((year) % 4) ? 365 : 366)

static void
validate_structure (tim_p)
     struct tm *tim_p;
{
  div_t res;
  int days_in_feb = 28;

  /* calculate time & date to account for out of range values */
  if (tim_p->tm_sec < 0 || tim_p->tm_sec > 59)
    {
      res = div (tim_p->tm_sec, 60);
      tim_p->tm_min += res.quot;
      if ((tim_p->tm_sec = res.rem) < 0)
        tim_p->tm_sec += 60;
    }

  if (tim_p->tm_min < 0 || tim_p->tm_min > 59)
    {
      res = div (tim_p->tm_min, 60);
      tim_p->tm_hour += res.quot;
      if ((tim_p->tm_min = res.rem) < 0)
        tim_p->tm_min += 60;
    }

  if (tim_p->tm_hour < 0 || tim_p->tm_hour > 23)
    {
      res = div (tim_p->tm_hour, 24);
      tim_p->tm_mday += res.quot;
      if ((tim_p->tm_hour = res.rem) < 0)
        tim_p->tm_hour += 24;
    }

  if (tim_p->tm_mon > 11)
    {
      res = div (tim_p->tm_mon, 12);
      tim_p->tm_year += res.quot;
      if ((tim_p->tm_mon = res.rem) < 0)
        tim_p->tm_mon += 12;
    }

  if (_DAYS_IN_YEAR (tim_p->tm_year) == 366)
    days_in_feb = 29;

  if (tim_p->tm_mday < 0)
    {
      while (tim_p->tm_mday < 0)
        {
          tim_p->tm_mday += _DAYS_IN_MONTH (tim_p->tm_mon);
          if (--tim_p->tm_mon == -1)
            {
              tim_p->tm_year--;
              tim_p->tm_mon = 12;
              days_in_feb =
                ((_DAYS_IN_YEAR (tim_p->tm_year) == 366) ?
                 29 : 28);
            }
        }
    }
  else
    {
      while (tim_p->tm_mday > _DAYS_IN_MONTH (tim_p->tm_mon))
        {
          tim_p->tm_mday -= _DAYS_IN_MONTH (tim_p->tm_mon);
          if (++tim_p->tm_mon == 12)
            {
              tim_p->tm_year++;
              tim_p->tm_mon = 0;
              days_in_feb =
                ((_DAYS_IN_YEAR (tim_p->tm_year) == 366) ?
                 29 : 28);
            }
        }
    }
}

time_t
mktime (tim_p)
     struct tm *tim_p;
{
  time_t tim = 0;
  long days = 0;
  int year;

  /* validate structure */
  validate_structure (tim_p);

  /* compute hours, minutes, seconds */
  tim += tim_p->tm_sec + (tim_p->tm_min * _SEC_IN_MINUTE) +
    (tim_p->tm_hour * _SEC_IN_HOUR);

  /* compute days in year */
  days += tim_p->tm_mday - 1;
  days += _DAYS_BEFORE_MONTH[tim_p->tm_mon];
  if (tim_p->tm_mon > 1 && _DAYS_IN_YEAR (tim_p->tm_year) == 366)
    days++;

  /* compute day of the year */
  tim_p->tm_yday = days;

  if (tim_p->tm_year > 10000
      || tim_p->tm_year < -10000)
    {
      return (time_t) -1;
    }

  /* compute days in other years */
  if (tim_p->tm_year > 70)
    {
      for (year = 70; year < tim_p->tm_year; year++)
        days += _DAYS_IN_YEAR (year);
    }
  else if (tim_p->tm_year < 70)
    {
      for (year = 69; year > tim_p->tm_year; year--)
        days -= _DAYS_IN_YEAR (year);
      days -= _DAYS_IN_YEAR (year);
    }

  /* compute day of the week */
  if ((tim_p->tm_wday = (days + 4) % 7) < 0)
    tim_p->tm_wday += 7;

  /* compute total seconds */
  tim += (days * _SEC_IN_DAY);

  return tim;
}
#endif
