/*                           PORTINFO.H                            */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 *
 *  This file should include all of the various information needed to
 *  port the program to other systems.  The file portinfo.c also 
 *  contains special routines needed by some systems.
 */

#ifndef PORTINFO_H
#define PORTINFO_H

/* Choices to define here are:  MSDOS, MVS, UNIX, MAC. */

#define UNIX

/* Define far if compiler does not */

#ifndef far
#define far
#endif

/* portinfo.h must define NATIVE_CHARS as one of these two values */

#define ASCII_CHARS  1
#define EBCDIC_CHARS 2

/* define native byte ordering here.  Options are HIGHTOLOW (most rational
   machines), LOWTOHIGH (ibm pc's) or PDP_ORDER */

#define HIGHTOLOW 1
#define LOWTOHIGH 2
#define PDP_ORDER 4

#ifndef CHAR
#define CHAR unsigned char
#endif

/* The following items are standard to ANSI-C but may not defined
   for all implementations.

   strerror()	: Return the system error message from the error number.
   vsprintf()	: Same as sprintf() but use a single variable argument list.
   <limits.h>   : Define the limits for the system.

   The IBM RT and VAX BSD systems do not the standard. */

#if defined(ibm032) || defined(vax) || defined(pyr)
#define DEFINE_STDERROR
#define DEFINE_VSPRINTF
#define DEFINE_STRTOL
#define DEFINE_LIMITS 
#define DEFINE_MKTIME
#endif

#ifdef DEFINE_MKTIME
#include <time.h>
#include <sys/types.h>
time_t mktime();
#endif

#ifdef __STDC__
#define PROTOTYPE
#endif

/* The defines for MVS */

#ifdef MVS

#define NATIVE_ORDER    HIGHTOLOW
#define NATIVE_CHARS    EBCDIC_CHARS

#define READBINARY      "rb"
#define READTEXT        "r"
#define WRITEBINARY     "wb"
#define WRITETEXT       "w"
#define READWRITEBINARY "rb+"
#define READWRITETEXT   "r+"

#ifndef MOVE /* guarantees overlapping string moves */
#define MOVE(to, from, n) movmem((void *) from, (void *) to, n)
#endif

#ifndef COPY /* does not guarantee overlapping string moves */
#define COPY(to, from, n) memcpy(to, from, (short)n)
#endif

#define WTOD(x,y) wtod(x,y)

#endif   /* MVS */

/* The defines for MSDOS */

#ifdef MSDOS

#define NATIVE_ORDER    LOWTOHIGH
#define NATIVE_CHARS    ASCII_CHARS

#define READBINARY      "rb"
#define READTEXT        "r"
#define WRITEBINARY     "wb"
#define WRITETEXT       "w"
#define READWRITEBINARY "rb+"
#define READWRITETEXT   "r+"

#ifndef MOVE /* guarantees overlapping string moves */
#define MOVE(to, from, n) memmove(to, from, n)
#endif

#ifndef COPY /* does not guarantee overlapping string moves */
#define COPY(to, from, n) memcpy(to, from, n)
#endif

#define WTOD(x,y)

#endif  /* MSDOS */

#ifdef UNIX

/*****************************************
 * The below define for void needed when
 * compiling on stupid 'C' compilers.
 *****************************************/
/*
#ifndef void
#define void int
#endif
*/

/* #define NATIVE_ORDER    HIGHTOLOW -- UNIX has MANY Orders */

#ifdef vax

#define NATIVE_ORDER LOWTOHIGH
#if !defined(ultrix)
#ifdef COPY /* does not guarantee overlapping string moves */
#undef COPY
#endif /* COPY */
#define COPY(to, from, n) bcopy((void *)from, (void *)to, n)
#endif /* !ultrix */

#else /* vax */
#ifdef ibm032
#define NATIVE_ORDER HIGHTOLOW
#else /* ibm032 */
#if defined (mips) && defined (ultrix)
#define NATIVE_ORDER LOWTOHIGH
#else /* mips && ultrix */
#if defined (_AIX) && defined (_IBMR2)
#define NATIVE_ORDER HIGHTOLOW
#else /* _AIX && _IBMR2 */
#if defined (i386)
#define NATIVE_ORDER LOWTOHIGH
#else /* i386 */
#if defined (sparc)
#define NATIVE_ORDER HIGHTOLOW
#else /* sparc */
#define       NATIVE_ORDER HIGHTOLOW      /* default big endian */
#endif /* sparc */
#endif /* _I386 */
#endif /* _AIX && _IBMR2 */
#endif /* mips && ultrix */
#endif /*ibm032 */
#endif /* vax */

#define NATIVE_CHARS    ASCII_CHARS

#define READBINARY      "r"
#define READTEXT        "r"
#define WRITEBINARY     "w"
#define WRITETEXT       "w"
#define READWRITEBINARY "r+"
#define READWRITETEXT   "r+"

#ifndef CTYPEH
#define CTYPEH
#include <ctype.h>
#endif

#ifdef tolower
#undef tolower
#endif
#define tolower(c) (isupper((c)) ? ((c)-'A'+'a') : (c))

#ifdef toupper
#undef toupper
#endif
#define toupper(c) (islower((c)) ? ((c)-'a'+'A') : (c))

#ifndef MOVE /* guarantees overlapping string moves */
#define MOVE(to, from, n) memmove((void *)to, (void *)from, n)
#endif

#ifndef COPY /* does not guarantee overlapping string moves */
#define COPY(to, from, n) memcpy((void *)to, (void *)from, n)
#endif

#define WTOD(x,y)

#endif  /* UNIX */


#ifdef MAC

/* The defines for MAC */

#include <ansi.h>

#define NATIVE_ORDER    HIGHTOLOW
#define NATIVE_CHARS    ASCII_CHARS

#define READBINARY      "r"
#define READTEXT        "r"
#define WRITEBINARY     "w"
#define WRITETEXT       "w"
#define READWRITEBINARY "r+"
#define READWRITETEXT   "r+"

#ifndef MOVE /* guarantees overlapping string moves */
#define MOVE(to, from, n) memmove((void *)to, (void *)from, n)
#endif

#ifndef COPY /* does not guarantee overlapping string moves */
#define COPY(to, from, n) memcpy((void *)to, (void *)from, n)
#endif

#define WTOD(x,y)

#endif  /* MAC */

#endif  /* PORTINFO_H */
