/*                            RECORD.C                            */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#include <stdio.h>

#include "msg.h"
#include "record.h"
#include "session.h"

extern int usmarc_display();
extern int info1_display();
extern int opac_display();
extern int sutr_display();
extern int diag_bib1_display();
extern int diag_unknown_display();

typedef struct record_entry
    {
        int  syntax;
        char *name;
        char *oid;
        int  (*routine)();
    } RECORD_ENTRY;

static RECORD_ENTRY record_table[] =
    {
        NORMAL,  "NORMAL",     "",                           NULL,
        USMARC,  "USMARC",     "1.2.840.10003.5.10",         usmarc_display,
	USMARC,  "UKMARC",     "1.2.840.10003.5.11",         usmarc_display,
        USMARC,  "CANMARC",    "1.2.840.10003.5.17",         usmarc_display,
        INFO1,   "INFO1",      "1.2.840.10003.5.1000.2.1",   info1_display,
        OPAC,    "OPAC",       "1.2.840.10003.5.1000.11.2",  opac_display,
        OPAC,    "OPAC",       "1.2.840.10003.5.102",        opac_display,
        OPAC,    "OPAC",       "1.2.840.10003.5.21",         opac_display,
        SUTR,    "SUTR",       "1.2.840.10003.5.101",        sutr_display,
        DIAG_B1, "DIAG_B1",    "1.2.840.10003.4.1",          diag_bib1_display,
        UNKNOWN, "UNKNOWN",    " ",                          diag_unknown_display
    };

char *record_oid_from_syntax(int syntax)
{
    RECORD_ENTRY *entry;

    for (entry = record_table; entry->syntax != UNKNOWN; entry++)
        {
            if (syntax == entry->syntax) break;
        }

    return entry->oid;
}

/*--------------------------------------------------------------*
 |                    EXPAND_SERIES                             |
 | Function:                                                    |
 |    Allocate the memory required for a record series.         |
 | Parameters:                                                  |
 |    series   : Pointer to a record series.                    |
 | Returns:                                                     |
 |    OK or NOTOK.                                              |
 | Description:                                                 |
 |    Allocate or reallocate the memory used for a record       |
 |    series.                                                   |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

int record_syntax_from_oid(char *oid)
{
    RECORD_ENTRY *entry;

    for (entry = record_table; entry->syntax != UNKNOWN; entry++)
        {
            if (strcmp(oid, entry->oid) == 0) break;
        }

    return entry->syntax;
}

/*--------------------------------------------------------------*
 |                    EXPAND_SERIES                             |
 | Function:                                                    |
 |    Allocate the memory required for a record series.         |
 | Parameters:                                                  |
 |    series   : Pointer to a record series.                    |
 | Returns:                                                     |
 |    OK or NOTOK.                                              |
 | Description:                                                 |
 |    Allocate or reallocate the memory used for a record       |
 |    series.                                                   |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

int record_syntax_from_name(char *name)
{
    RECORD_ENTRY *entry;

    for (entry = record_table; entry->syntax != UNKNOWN; entry++)
        {
            if (strcmp(name, entry->name) == 0) break;
        }

    return entry->syntax;
}

/*
 *
 *                    RECORD_DISPAY
 * Function:
 *    Output the records according to the display in the
 *    table.
 * Parameters:
 *    session  : Session information.
 *    record   : Pointer to the record to output.
 * Returns:
 *    Nothing.
 * Description:
 *    Depending on the type of record, output the record.
 * Note:
 *
 */


int record_display(SESSION *session,
                   RECORD *record,
                   int position)
{
    RECORD_ENTRY *entry;
    int status;

    for (entry = record_table; entry->syntax != UNKNOWN; entry++)
        {
            if (record->syntax == entry->syntax) break;
        } 

    if (record->length < 0 || record->location == NULL)
        status = msg_make(INVALID_RECORD, position);
    else
        status = (*entry->routine)(session, record, position);

    return status;
}
