/*                            SCAN.H                             */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#ifndef SCAN_H
#define SCAN_H

#ifndef SERIES_H
#include "series.h"
#endif

#ifndef SESSION_H
#include "session.h"
#endif

#ifndef STRINGS_H
#include "strings.h"
#endif

typedef struct scan_record
    {
        char    *dbname;        /* Database Name */
        int     occurences;     /* Type of scan */
        int     condition;      /* Condition code -- only for errors */
        STRING  term;           /* Place of scan */
    } SCAN;

typedef struct scan_info
    {
        unsigned int  stepsize;
        unsigned int  returned;
        unsigned int  position;
        signed   int  status;
        char         *dbname;
        SERIES *records;
        SERIES *errors;
    } SCAN_INFO;

#define scaninfo_set_stepsize(info,x)  (info)->stepsize = x
#define scaninfo_set_returned(info,x)  (info)->returned = x
#define scaninfo_set_position(info,x)  (info)->position = x
#define scaninfo_set_status(info,x)    (info)->status = x
#define scaninfo_set_dbname(info,x)    (info)->dbname = x

#define scaninfo_get_stepsize(info)    (info)->stepsize
#define scaninfo_get_returned(info)    (info)->returned
#define scaninfo_get_position(info)    (info)->position
#define scaninfo_get_status(info)      (info)->status
#define scaninfo_get_dbname(info)      (info)->dbname

SCAN_INFO *scaninfo_new();

void scaninfo_extract(SCAN_INFO *info,
                      DATA_DIR  *ber);

void scaninfo_output(SESSION *session,
		     SCAN_INFO  *info);

void scaninfo_dispose(SCAN_INFO **info);

#endif
