/*                            SESSION.H                            */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#ifndef SESSION_H
#define SESSION_H

#ifndef BERUTIL_H
#include "berutil.h"
#endif

#ifndef NETIO_H
#include "netio.h"
#endif

#ifndef DATABASE_H
#include "database.h"
#endif

#ifndef Z3950_H
#include "z3950.h"
#endif

#define SSIZE            40              /* String size */

typedef struct session_descriptor
    {
        int  state;                      /* Session state */
        DATA_DIR *pdu;                   /* Session pdu */
        DATA_DIR *rdu;                   /* Record du */
        DATABASE_REFERENCE db;           /* Database info */
        NETIO_REFERENCE io;              /* IO information */
        char *target_name;               /* The Target Implementors Name */
        char *reference;                 /* Reference */
        int  preferred_msg_size;         /* Preferred Message Size */
        int  maximum_msg_size;           /* Maximum Message Size */
        char option[MAX_OPTIONS+1];      /* Options */
        char host[SSIZE];                /* Host */
        char set_name[SSIZE];            /* Set name */
        char current_set[SSIZE];         /* Current set name */
        char elemset_name[SSIZE];        /* The element set name to use */
        int  marc_type;                  /* Marc Type --STANFORD ONLY-- */
        int  preferred_syntax;           /* Preferred syntax */
        int  result_count;               /* Result count from search */
        int  next_record;                /* Next record */
        int  set_replace;                /* Replace set */
        int  set_small_limit;            /* Small set limit */
        int  set_large_limit;            /* The large limit */
        int  set_medium_limit;           /* The medium display limit */
        int  (*access_control)();        /* Access control routine */
        int  (*resource_control)();      /* Resource control routine */
        int  (*user_timeout)();          /* timeout routine */
        int  (*user_cancel)();           /* call back for cancel routine */
        int  wait_for_pdu;               /* Wait for the PDU packet */

    } SESSION;

/* Function prototypes */

int session_servers();

SESSION *session_new(char *name, 
		     char *host, 
		     char *port, 
		     char **authorize);

int session_dispose(SESSION **session);

/* Defines for used values */

#define session_host(x)  (x)->io->host

#define session_setname(x) (x)->current_set

#endif


