/*                            STRINGS.H                            */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#ifndef STRINGS_H
#define STRINGS_H

#include <string.h>

typedef struct string
    {
        unsigned int length;
        char *location;
    } STRING, *STRING_REFERENCE;

#define string_length(s) ((s).length)

#define string_location(s) ((s).location)

#define STRING_DESCRIPTORS_EQUAL(d1,d2) \
    (((d1).length == (d2).length) && ((d1).location == (d2).location))

#define STRINGS_EQUAL(s1,s2) \
    (   ((s1).length == (s2).length) \
     && (     ((s1).length == 0) \
           || (memcmp((s1).location, (s2).location, (s1).length) == 0) \
        ) \
    )
#define STRING_SET(s,x,y)  (s).length = x, (s).location = y

/* Function prototypes */

void str_uc(STRING *string);
void str_squ(STRING *original, STRING *squeezed);
int str_cmp(STRING *one, STRING *two);
int str_ccmp(STRING *one, char *two);
void str_dup(STRING *source, STRING *duplicate);
void str_cat(STRING *source, STRING *concat);
void str_ccat(STRING *source, char *concat);
int str_trim(STRING *source);

#define string_upper(x)              str_uc(x)
#define string_squeeze(x,y)          str_squ(x,y)
#define string_compare(x,y)          str_cmp(x,y)
#define string_ccompare(x,y)         str_ccmp(x,y)
#define string_duplicate(x,y)        str_dup(x,y)
#define string_concatenate(x,y)      str_cat(x,y)
#define string_cconcatenate(x,y)     str_ccat(x,y)
#define string_trim(x)               str_trim(x)

#endif
