/*                             INFO1.C                             */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#include <stdio.h>

#include "berutil.h"
#include "constant.h"
#include "pdutags.h"
#include "putget.h"
#include "record.h"
#include "session.h"
#include "strings.h"

/*--------------------------------------------------------------*
 |                  SUTR_DISPLAY                                |
 | Function:                                                    |
 |    Display Simple-Unstructured-Text records                  |
 | Parameters:                                                  |
 |    record   : The pointer to the SUTR record.                |
 |    length   : Length of the record.                          |
 |    position : The ordinal position in the result.            |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |    Just get the elements and display them.                   |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

static void output_text(int position,
			char *text,
                        int length)
{
    extern FILE *out;

#ifndef MARKER

    fprintf(out, "Record %d\n", position);

    fwrite(text, length, 1, out); 

    fprintf(out, "\n");
#else
    fprintf(out, "\naddupd;\nID = %d;\nTEXT = \"", position);
     
    for(; length > 0; length--, text++)
	{
	    /*
	     * To reduce the number of comparison instructions
	     * for most characters split the check for NL and CR 
             * apart.  The output should be as follows:
	     *
	     *      "    > '""'            (double any quotes)
             *      NL   > '";             
             *             TEXT = "'       (new text element)
             *      CR   > ''              (skip CR, no output)  
             *      0x?? > 0x??            (copy char to output)
	     *
	     * This will only work for ASCII text.
	     */

	    if (*text > CR)
		{
		    putc(*text, out);

		    if (*text == DOUBLE_QUOTE)
			putc(*text, out);
		}
	    else
		{
		    if (*text == NL)
			fputs("\";\nTEXT = \"", out);
		    else if (*text != CR)
			putc(*text,out);
		}
	}
    
    fputs("\";\n", out);

#endif
}

/*--------------------------------------------------------------*
 |                  SUTR_DISPLAY                                |
 | Function:                                                    |
 |    Display Simple-Unstructured-Text records                  |
 | Parameters:                                                  |
 |    record   : The pointer to the SUTR record.                |
 |    length   : Length of the record.                          |
 |    position : The ordinal position in the result.            |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |    Just get the elements and display them.                   |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

int sutr_display(SESSION *session,
                 RECORD *record,
                 int position)
{
    DATA_DIR *rec = session->rdu;
    
    if (   bld_dir((CHAR *) record->location, rec) == 0
        || rec->fldid != GENERALSTR)
	{
	    /*
	     * Some servers seem  to return the SUTR wrapped
	     * in BER while others just return the text.  This
	     * takes care of the case where there is no BER
	     * wrapper.
	     */

	    output_text(position, record->location, record->length);
	}
    else
	{
	    STRING text;

	    /* The text was wrapped in BER */
	    
	    get_string(rec, GENERALSTR, &text, REQUIRED);

	    output_text(position, text.location, text.length);
	}
   return 0;
}
