/*                            TRIGGER.C                             */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

/* More error checking is needed */

#include "constant.h"
#include "msg.h"
#include "pdutags.h"
#include "putget.h"
#include "session.h"

enum trigger_control_tags
{
    RequestedAction = 46,
    PreferredResourceReportFormat,
    ResultSetWanted
};

enum requested_action_tags
{
    ResourceReport = 1,
    ResourceControl,
    Cancel
};

/*--------------------------------------------------------------*
 |             ENCODE_TRIGGERRESOURCECONTROL_REQUEST            |
 | Function:                                                    |
 |    Encode the Trigger Resource Control Request.              |
 | Parameters:                                                  |
 |    session   : Session information.                          |
 |    action    : Trigger action.                               |
 |    setwanted : A result set wanted from a search             |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

void Encode_TriggerResourceControl_Request(SESSION *session,
                                           int action,
                                           int setwanted)
{
    DATA_DIR *PTrig;
    int previous_request;

    /* Save the previous request to see if a Search */

    previous_request = session->pdu->fldid;

    PTrig = put_begin(session->pdu, TriggerResourceControlRequest);
    if (PTrig == NULL_DIR) return;

    if (session->reference)
        put_cstring(PTrig, ReferenceId, session->reference);

    put_int(PTrig, RequestedAction, action);

/*----------------------------------------
    if (action == ResourceReport && session->pref_resource != NULL)
        put_oid(PTrig, PreferredResourceReportFormat, session->pref_resource);
------------------------------------------*/


    /* Result set wanted is only meaningful during a Search */

    if (action == Cancel && previous_request == SearchRequest)
        put_flag(PTrig, ResultSetWanted, setwanted);

}

/*--------------------------------------------------------------*
 |                 SEND_TRIGGER_CONTROL_PDU                     |
 | Function:                                                    |
 |    Reply to an access control pdu request.                   |
 | Parameters:                                                  |
 |    session : Session information.                            |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |    Responds to the access control with a blank password      |
 |    unless there is an access control routine to call.        |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

int send_trigger_control_pdu(SESSION *session,
                             int action,
                             int setwanted)
{
    Encode_TriggerResourceControl_Request(session, action, setwanted);
    if (MSG_TEST == OK)
        {
            transmit_pdu(session,
                         session->pdu,
                         TriggerResourceControlRequest,
                         WAIT_TRIGGER);
        }
    return MSG_TEST;
}
