/*                            UTILITY.C                            */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#include <ctype.h>
#include <string.h>

#include "constant.h"
#include "msg.h"

/*--------------------------------------------------------------*
 |                    UPPERCASE                                 |
 | Function:                                                    |
 |    Copy the characters into another string in uppercase.     |
 | Parameters:                                                  |
 |    upper    : Pointer to string to receive uppercase string  |
 |    word     : Pointer to string to translate to uppercase.   |
 |    length   : Length of word to translate                    |
 | Returns:                                                     |
 |    Nothing                                                   |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |    Some version of C toupper() may only convert lowercase    |
 |    characters, therefore the need of the islower() function. |
 *--------------------------------------------------------------*/

void uppercase(upper, word, length)
    char *upper;
    char *word;
    int  length;
{
    for (; length-- > 0; upper++, word++)
        {
            if (islower(*word)) *upper = toupper(*word);
            else if (word != upper) *upper = *word;
        }

    if (word != upper) *upper = EOS;
}

/*--------------------------------------------------------------*
 |                    TOKENIZE                                  |
 | Function:                                                    |
 |    Get the next token in the string.                         |
 | Parameters:                                                  |
 |    string    : Address to string to parse.                   |
 |    word      : Address of string to place next token (word). |
 |    delimiter : Address of character delimiter.               |
 | Returns:                                                     |
 |    length of the token.                                      |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |    The delimiter is returned so that a quoted string can be  |
 |    distinguished from a un-quoted string.                    | 
 |                                                              |
 *--------------------------------------------------------------*/

int tokenize(char **string, 
	     char **word, 
	     const char *break_characters)
{
    char delimiter;
    char *phrase = *string;

    /* Skip over blanks */

    while (*phrase == BLANK || *phrase == TAB) phrase++;

    /* Check for a delimiter */

    *word = phrase;

    if (*phrase == QUOTE || *phrase == DOUBLE_QUOTE)
        delimiter = *phrase++;
    else
        delimiter = EOS;

    /* Span the token */

    for (; *phrase; phrase++)
        {
            if (*phrase == delimiter)
                {
                    phrase++;

                    if (*phrase != delimiter)
                        {
                            delimiter = EOS;
                            break;
                        }
                }

            if (delimiter == EOS && strchr(break_characters,*phrase))
                break;
        }
    *string = phrase;

    /* Check if delimiter was matched */

    if (delimiter != EOS)
        return msg_make(MISSING_QUOTE, *word);

    return (int) (phrase - *word);
}
