/*                            WAITIO.C                             */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#include <sys/types.h>
#include <sys/time.h>
#include <stdio.h>

#ifdef _AIX
#include <sys/select.h>
#endif

#ifndef ANSI
#include <memory.h>
#endif

#include "constant.h"

#define NULL_FDSET             (fd_set *) NULL

/*--------------------------------------------------------------*
 |                     FD_WAIT                                  |
 | Function:                                                    |
 |    Wait for input on the network.                            |
 | Parameters:                                                  |
 |    io             : Pointer to network information.          |
 |    seconds_wait   : Number of seconds to wait.               |
 |    useconds_wait  : Number of microseconds to wait.          |
 | Returns:                                                     |
 |    Nothing.                                                  |
 | Description:                                                 |
 |    Wait for a set amount of time for information to          |
 |    appear on the network.                                    |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

int fd_wait(int   seconds_wait,
            long  useconds_wait,
            int   max_index,
            int   file_descriptors[])
{
    struct  timeval holdtime;
    struct  timeval *timeout = &holdtime;
    fd_set  read_fds;
    int     fd_index;
    int     max_fds = 0;
    int     ready;
    long    total;

    total = useconds_wait + seconds_wait;

    if (total < 0)                   /* Wait indefinitely */
        timeout = NULL;
    else if (total == 0)            /* Poll the socket */
        {
            timeout->tv_sec = 0;
            timeout->tv_usec = 0;
        }
    else                             /* Wait n microseconds */
        {
            timeout->tv_sec = seconds_wait;
            timeout->tv_usec = useconds_wait;
        }

    FD_ZERO(&read_fds);
    if (max_index <= 0) return -1;

    while (max_index -- > 0)
        {
            FD_SET(file_descriptors[max_index], &read_fds);
            max_fds = MAX(max_fds, file_descriptors[max_index]);
        }

    /* Wait for read */

    max_fds++;

    ready = select(max_fds, &read_fds, NULL_FDSET, NULL_FDSET, timeout);

    return ready;
}
