/*                             Z3950.H                             */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */
/* Log:
 * 04/25/94  slh  put in bjordan's NO_TRUNCATION_MARK define
 */

#ifndef Z3950_H
#define Z3950_H

/* Default Z39.50 server host and port */

#define Z3950_HOST         "INFOCAL.BERKELEY.EDU"
#define Z3950_PORT          "210"           /* Default port number */

/* Miscellaneous constants */

#define LOG_DEFAULT         ""              /* Log file used by default     */
#define MSG_DEFAULT         ""              /* Message log file used by default */
#define LOG_FILENAME        "z3950.log"     /* Log file used by -l argument */
#define MSG_FILENAME        "z3950.msg"     /* Message log file used by -m arg */
#define DISPLAY_NUMBER      10              /* Number of records to retrieve */
#define SCAN_NUMBER         25              /* # of scan values to retrieve */
#define SCAN_POSITION       5               /* Scan position in values */
#define SET_INDICATOR       '@'             /* Character indicates set name */
#define DIR_BLOCKS          100             /* Number of blocks to allocate */
#define SERIES_SIZE         20              /* Size of record series */
#define TRUNCATION_MARK     "#?"            /* Truncation mark '#' & '?' */
#define NO_TRUNCATION_MARK  "|"             /* No truncation  */
#define ATTRIB_DELIM        "/"             /* Seperates attributes specified with index term */
#define ATTRIB_ASSIGN       ":"             /* Attribute assignment for <type><assign><value> */

/* Various number from the protocol options */

#define PROTOCOL_VERSION    "11"            /* The Z39.50 protocol version */
#define PREFERRED_MESSAGE   24000           /* The preferred message size  */
/* #define PREFERRED_MESSAGE   16384 */          /* The preferred message size  */
#define MAXIMUM_MESSAGE     32768           /* The maximum message size */

/* Options */

#define OPT_SEARCH          0               /* Bit  0 - Search */
#define OPT_PRESENT         1               /* Bit  1 - Present */
#define OPT_DELSET          2               /* Bit  2 - DelSet */
#define OPT_RESOURCERPRT    3               /* Bit  3 - ResourceReport */
#define OPT_TRIGGER         4               /* Bit  4 - TriggerResourceCtrl */
#define OPT_RESOURCECTRL    5               /* Bit  5 - ResourceCtrl */
#define OPT_ACCESSCTRL      6               /* Bit  6 - AccessCtrl */
#define OPT_SCAN            7               /* Bit  7 - Scan */
#define OPT_SORT            8               /* Bit  8 - Sort */
#define OPT_9               9               /* Bit  9 - Reserved */
#define OPT_REINIT          10              /* Bit 10 - ReInit */
#define OPT_RELEASE         11              /* Bit 11 - Release */
#define OPT_SORTINSEARCH    12              /* Bit 12 - SortInSearch */
#define OPT_EXPLAIN         13              /* Bit 13 - Explain */
#define OPT_SEG1LVL         14              /* Bit 14 - Level 1 Segmentation */
#define OPT_SEG2LVL         15              /* Bit 15 - Level 2 Segmentation */
#define OPT_CONCURRENT      16              /* Bit 16 - ConcurrentOperations */
#define OPT_NAMEDSETS       17              /* Bit 17 - Named Result Sets */
#define OPT_ABORT           18              /* Bit 18 - Abort */

/* Bits must be set for every one of the options above, 1 for on, 0 for off */
/* This maps the positions   0123456789012  so the bits can be set easily.  */

#define OPTIONS             "11111111"
#define MAX_OPTIONS         (sizeof(OPTIONS)-1)     /* Subtract EOS char */

/* Implementation */

#define CLIENT_ID           "1991"          /* Implementation id */
#define CLIENT_NAME         "Stanford University Z39.50 Client"
#define CLIENT_VERSION      "1.2a"           /* Implementation version */

/* Amount of time to wait for commands to finish */

#define WAIT_OPEN           60              /* Sec. wait for a connection */
#define WAIT_SEARCH         120             /* Sec. wait for a search */
#define WAIT_PRESENT        120             /* Sec. wait for a retrieve */
#define WAIT_SCAN           120             /* Sec. wait for a scan */
#define WAIT_CLOSE          60              /* Sec. wait for a close */
#define WAIT_TRIGGER        30              /* Sec. wait for a trigger */

/*
   The following explains the limits when retrieving elements
   during a find (search request).

   Which element set which is used and the number of records
   returned the records is based on the number of hits obtained
   obtained by the search.  The algorithm used is as follows:

   if number_of_hits <= small_set_limit
      return all records (subject to message size)
      composed of the small element name set.
   else if number_of_hits >= large_set_limit
      return no records
   else
      return a maximum of medium_set_number records
      composed of the medium element name set.

   Currently this is set to return a medium set.
*/

#define SMALL_SET_LIMIT     0               /* Maximum # res in a small set */
#define MEDIUM_SET_NUMBER   DISPLAY_NUMBER  /* Number of recs to retrieve */
#define LARGE_SET_LIMIT     1               /* Minimum # recs in a large set */
/* #define LARGE_SET_LIMIT     INT_MAX    */      /* Minimum # recs in a large set */

/*
   Trigger Resource Control Constants
*/
#define TRIG_RESOURCE_REPORT 1
#define TRIG_RESOURCE_CONTROL 2
#define TRIG_CANCEL 3
#endif
