/*                             MAIN.C                              */

/*
 *  Copyright (c) 1992 Stanford Leland Junior University
 *
 *  Commercial use prohibited
 *
 *  Author: Harold Finkbeiner (Harold@Forsythe.Stanford.Edu)
 */

#include <stdio.h>

#include "client.h"
#include "constant.h"
#include "z3950.h"

/*                                                              */
/* Here is where all of the global (external) variables are     */
/* declared.                                                    */
/*                                                              */

int debug = 0;             /* Debug flag (0 - no debugging)     */
FILE *in;                  /* Input file                        */
FILE *out;                 /* Output file                       */
FILE *log;                 /* Log file                          */
FILE *msg_log;             /* Message Log file                  */

/*--------------------------------------------------------------*
 |                    MAIN                                      |
 | Function:                                                    |
 |    Call the Z39.50 client.                                   |
 | Parameters:                                                  |
 |    None                                                      |
 | Returns:                                                     |
 |    Nothing                                                   |
 | Description:                                                 |
 |                                                              |
 | Note:                                                        |
 |                                                              |
 *--------------------------------------------------------------*/

void main(int argc,
	  char *argv[])
{
    char *logname = LOG_DEFAULT;
    char *msgname = MSG_DEFAULT;
    int  count;
    int  terse = 0;

    /* Check for any valid arguements */

    for (count = 1; count < argc; count++)
        {
            if (strcmp("-terse", argv[count]) == 0)
                {
                    /* Terse */

                    terse = 1;
                }
            else if (strcmp("-l", argv[count]) == 0)
                {
                    /* Default log file name */

                    logname = LOG_FILENAME;

                    /* If next parameter is not an option use it as logfile */

                    if (count+1 < argc && *argv[count+1] != '-')
                        logname = argv[++count];
                }
            else if (strcmp("-m", argv[count]) == 0)
                {
                    /* Default message log file name */

                    msgname = MSG_FILENAME;

                    /* If next parameter is not an option use it as logfile */

                    if (count+1 < argc && *argv[count+1] != '-')
                        msgname = argv[++count];
                }
            else
                fprintf(stderr, "-Invalid option %s.\n", argv[count]);
        }

    /* If a log file indicated then open the file */

    if (logname[0] != EOS)
        {
            log = fopen(logname,"a");
            if (log == NULL)
                fprintf(stderr, "Unable to open the log file %s.\n", logname);
        }
    else
        log = (FILE *) NULL;

    /* If a message log file indicated then open the file */

    if (msgname[0] != EOS)
        {
            msg_log = fopen(msgname,"a");
            if (msg_log == NULL)
                fprintf(stderr, "Unable to open the log file %s.\n", msgname);
        }
    else
        msg_log = (FILE *) NULL;

    in = stdin;
    out = stdout;

    z3950_client(terse);

    if (log) fclose(log);
    if (msg_log) fclose(log);
}
